@@ -7,12 +7,15 @@ import causalpy as cp
 DATASETS = {
     "banks": {"filename": "banks.csv"},
     "brexit": {"filename": "GDP_in_dollars_billions.csv"},
+    "covid": {"filename": "deaths_and_temps_england_wales.csv"},
     "did": {"filename": "did.csv"},
     "drinking": {"filename": "drinking.csv"},
     "its": {"filename": "its.csv"},
     "its simple": {"filename": "its_simple.csv"},
     "rd": {"filename": "regression_discontinuity.csv"},
     "sc": {"filename": "synthetic_control.csv"},
+    "anova1": {"filename": "ancova_generated.csv"},
+    "geolift1": {"filename": "geolift1.csv"},
 }
 
 
