@@ -1,10 +1,12 @@
-from typing import Any, Dict, Optional, Union
+from typing import Any, Dict, Optional, Tuple, Union
 
 import arviz as az
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 import xarray as xr
+from matplotlib.collections import PolyCollection
+from matplotlib.lines import Line2D
 
 
 def plot_xY(
@@ -13,28 +15,35 @@ def plot_xY(
     ax: plt.Axes,
     plot_hdi_kwargs: Optional[Dict[str, Any]] = None,
     hdi_prob: float = 0.94,
-    include_label: bool = True,
-) -> None:
+    label: Union[str, None] = None,
+) -> Tuple[Line2D, PolyCollection]:
     """Utility function to plot HDI intervals."""
 
     if plot_hdi_kwargs is None:
         plot_hdi_kwargs = {}
 
-    az.plot_hdi(
+    (h_line,) = ax.plot(
+        x,
+        Y.mean(dim=["chain", "draw"]),
+        ls="-",
+        **plot_hdi_kwargs,
+        label=f"{label}",
+    )
+    ax_hdi = az.plot_hdi(
         x,
         Y,
         hdi_prob=hdi_prob,
         fill_kwargs={
             "alpha": 0.25,
-            "label": f"{hdi_prob*100}% HDI" if include_label else None,
+            "label": " ",
         },
         smooth=False,
         ax=ax,
         **plot_hdi_kwargs,
     )
-    ax.plot(
-        x,
-        Y.mean(dim=["chain", "draw"]),
-        color="k",
-        label="Posterior mean" if include_label else None,
-    )
+    # Return handle to patch. We get a list of the childen of the axis. Filter for just
+    # the PolyCollection objects. Take the last one.
+    h_patch = list(
+        filter(lambda x: isinstance(x, PolyCollection), ax_hdi.get_children())
+    )[-1]
+    return (h_line, h_patch)
